@@ -11,6 +11,7 @@ import SciMLBase: isdualtype, DualEltypeChecker, sse, __sum
 
 const dualT = ForwardDiff.Dual{ForwardDiff.Tag{OrdinaryDiffEqTag, Float64}, Float64, 1}
 dualgen(::Type{T}) where {T} = ForwardDiff.Dual{ForwardDiff.Tag{OrdinaryDiffEqTag, T}, T, 1}
+dualgen(::Type{T}, ::Val{CS}) where {T, CS} = ForwardDiff.Dual{ForwardDiff.Tag{OrdinaryDiffEqTag, T}, T, CS}
 
 const NORECOMPILE_IIP_SUPPORTED_ARGS = (
     Tuple{
@@ -85,6 +86,41 @@ function wrapfun_iip(
     return FunctionWrappersWrappers.FunctionWrappersWrapper{typeof(fwt), false}(fwt)
 end
 
+# 3-arg version: compile FunctionWrapper variants with the specified chunk size.
+# Uses chunk=CS for u-related duals (Jacobian computation) and chunk=1 for
+# t-related duals (time derivative is always scalar, so chunk=1).
+function wrapfun_iip(
+        ff,
+        inputs::Tuple{T1, T2, T3, T4},
+        ::Val{CS}
+    ) where {T1, T2, T3, T4, CS}
+    T = eltype(T2)
+
+    # Jacobian (u-derivative) uses chunk=CS
+    dualT_jac = dualgen(T, Val(CS))
+    dualT1_jac = ArrayInterface.promote_eltype(T1, dualT_jac)
+    dualT2_jac = ArrayInterface.promote_eltype(T2, dualT_jac)
+
+    # Time derivative uses chunk=1 (scalar differentiation w.r.t. t)
+    dualT_time = dualgen(T)
+    dualT1_time = ArrayInterface.promote_eltype(T1, dualT_time)
+    dualT4_time = dualgen(promote_type(T, T4))
+
+    iip_arglists = (
+        Tuple{T1, T2, T3, T4},                                  # plain
+        Tuple{dualT1_jac, dualT2_jac, T3, T4},                  # Jacobian (u dual, chunk=CS)
+        Tuple{dualT1_time, T2, T3, dualT4_time},                # time derivative (chunk=1)
+        Tuple{dualT1_jac, dualT2_jac, T3, dualT4_time},         # both
+    )
+
+    iip_returnlists = ntuple(x -> Nothing, 4)
+
+    fwt = map(iip_arglists, iip_returnlists) do A, R
+        FunctionWrappersWrappers.FunctionWrappers.FunctionWrapper{R, A}(Void(ff))
+    end
+    return FunctionWrappersWrappers.FunctionWrappersWrapper{typeof(fwt), false}(fwt)
+end
+
 const iip_arglists_default = (
     Tuple{
         Vector{Float64}, Vector{Float64}, Vector{Float64},
