@@ -17,7 +17,7 @@ prob = ODEProblem(f, [x], tspan)
 
 # Should not error during problem construction but should be unwrapped
 integ = init(prob, Tsit5(), dt = 0.1)
-@test integ.f.f === f
+@test SciMLBase.unwrapped_f(integ.f.f) === f
 
 # Handle functional initial conditions
 prob = ODEProblem((dx, x, p, t) -> (dx .= 0), (p, t) -> zeros(2), (0, 10))
