@@ -346,20 +346,20 @@ u0 = [1.0 + 1im, 2.0, 3.0]
 @test DiffEqBase.promote_u0(u0, p, t) isa AbstractArray{<:Complex{<:ForwardDiff.Dual}}
 
 # Issue https://github.com/SciML/NonlinearSolve.jl/issues/440
-f(u, p, t) = [u[2], 1.5u[1]^2]
-ode = ODEProblem(f, [0.0, 0.0], (0, 1))
+f_nlsolve(u, p, t) = [u[2], 1.5u[1]^2]
+ode = ODEProblem(f_nlsolve, [0.0, 0.0], (0, 1))
 @inferred DiffEqBase.anyeltypedual(ode)
-ode = NonlinearProblem(f, [0.0, 0.0], (0, 1))
+ode = NonlinearProblem(f_nlsolve, [0.0, 0.0], (0, 1))
 @inferred DiffEqBase.anyeltypedual(ode)
 
 # Issue https://github.com/SciML/DiffEqBase.jl/issues/1021
-f(u, p, t) = 1.01 * u
+f_1021(u, p, t) = 1.01 * u
 struct Foo{T}
     sol::T
 end
 u0 = 1 / 2
 tspan = (0.0, 1.0)
-prob = ODEProblem{false}(f, u0, tspan)
+prob = ODEProblem{false}(f_1021, u0, tspan)
 foo = SciMLBase.build_solution(
     prob, DiffEqBase.InternalEuler.FwdEulerAlg(), [u0, u0], [0.0, 1.0]
 )
